/*
 * DemosceneMusic - LoginPage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.User;
import net.pterodactylus.util.database.DatabaseException;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.Method;
import net.pterodactylus.util.web.RedirectException;

/**
 * Page that lets the user log in with his username and his password.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class LoginPage extends BasePage {

	/**
	 * Creates a new login page.
	 *
	 * @param core
	 *            The core
	 * @param templateContextFactory
	 *            The template context factory
	 * @param template
	 *            The template to render
	 */
	public LoginPage(Core core, TemplateContextFactory templateContextFactory, Template template) {
		super(core, templateContextFactory, template, "login");
	}

	//
	// BASEPAGE METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		if (request.getMethod() == Method.POST) {
			String username = request.getServletRequest().getParameter("username");
			String password = request.getServletRequest().getParameter("password");
			try {
				User user = getCore().getDataManager().getUserByName(username);
				if (user == null) {
					templateContext.set("error", "user-not-found");
					return;
				}
				if (!user.verifyPassword(password)) {
					templateContext.set("error", "invalid-password");
					return;
				}
				/* credentials okay, log the user in. */
				request.getServletRequest().getSession().setAttribute("currentUser", user);
				throw new RedirectException(".");
			} catch (DatabaseException de1) {
				throw new RuntimeException("Could not load user from database.", de1);
			}
		}
	}

}
